pydocmd
=======

pydocmd generates Python Module / script documentation in the Markdown (md)
format. It was written to automatically generate documentation that can be put
on Github or Bitbucket.

It is as of yet not very complete and is more of a Proof-of-concept than a
fully-fledged tool. Markdown is also a very restricted format and every
implementation works subtly, or completely, different. This means output
may be different on different converters.

* __Author__: Ferry Boender <ferry.boender@gmail.com>
* __Version__: 0.1
* __Copyright__: Copyright 2014, Ferry Boender
* __License__: MIT (expat) License

Usage
-----

    ./pydocmd file.py > file.md

Example output
--------------

* https://github.com/fboender/pydocmd/wiki/Example-output-1
* https://github.com/fboender/pydocmd/wiki/Example-output-2

